Serializer

Struct Serializer 

pub struct Serializer<'xml, W: Write + ?Sized> { /* private fields */ }
XML serializer for writing structured XML output

Implementations

Source

impl<'xml, W: Write + ?Sized> Serializer<'xml, W>

pub fn new(output: &'xml mut W) -> Self

Create a new serializer writing to the given output

pub fn write_start<'a, const N: usize>( &mut self, name: &'a str, ns: &str, cx: Option<Context<N>>, ) -> Result<Element<'a, N>, Error>

Write the opening tag for an element

Returns the namespace prefix if one was used.

The cx parameter can be used to specify namespace declarations for the element. When passing in None, you’ll probably need to specify None::<Context<0>>.

pub fn write_attr<V: ToXml + ?Sized>( &mut self, name: &str, ns: &str, value: &V, ) -> Result<(), Error>

Write an attribute with the given name and value

pub fn write_str<V: Display + ?Sized>(&mut self, value: &V) -> Result<(), Error>

Write a string value (text content or attribute value)

pub fn end_start(&mut self) -> Result<(), Error>

Complete the opening tag and transition to element content

pub fn end_empty(&mut self) -> Result<(), Error>

Close an empty element (self-closing tag)

pub fn write_close<const N: usize>( &mut self, element: Element<'_, N>, ) -> Result<(), Error>

Write the closing tag for an element

pub fn prefix(&self, ns: &str) -> Option<&'static str>

Get the prefix for a namespace URI, if any

pub fn default_ns(&self) -> &'static str

Get the current default namespace URI